@@ -2,9 +2,18 @@ from collections.abc import Iterable
 from datetime import datetime
 
 
+def format_host(host):
+    """Formats host for PySense"""
+    if not host.startswith('http'):
+        host = 'http://' + host
+    if host.endswith('/'):
+        host = host[:-1]
+    return host
+
+
 def make_iterable(obj):
     """Makes object iterable"""
-    if obj is None: 
+    if obj is None:
         return []
     if not isinstance(obj, Iterable):
         return [obj]
@@ -13,4 +22,4 @@ def make_iterable(obj):
 
 def sisense_time_to_python(datetime_str):
     """Converts a Sisense date time to a python date time."""
-    return datetime.strptime(datetime_str[: -5], '%Y-%m-%dT%H:%M:%S')
\ No newline at end of file
+    return datetime.strptime(datetime_str[: -5], '%Y-%m-%dT%H:%M:%S')
